@@ -559,7 +559,7 @@ bitflags! {
        /// `F_SEAL_WRITE`.
        const WRITE = c::F_SEAL_WRITE;
        /// `F_SEAL_FUTURE_WRITE` (since Linux 5.1)
-       #[cfg(target_os = "linux")]
+       #[cfg(any(target_os = "android", target_os = "linux"))]
        const FUTURE_WRITE = c::F_SEAL_FUTURE_WRITE;
     }
 }
@@ -807,7 +807,6 @@ pub type FsWord = u32;
 ))]
 pub type FsWord = u64;
 
-/// `__fsword_t`
 // s390x uses `u32` for `statfs` entries, even though `__fsword_t` is `u64`.
 #[cfg(all(target_os = "linux", target_arch = "s390x"))]
 pub type FsWord = u32;
