@@ -238,14 +238,13 @@ pub unsafe fn fork() -> io::Result<Option<Pid>> {
 #[inline]
 #[cfg(linux_raw)]
 pub unsafe fn execveat<Fd: AsFd>(
-    dirfd: &Fd,
+    dirfd: Fd,
     path: &ZStr,
     argv: *const *const u8,
     envp: *const *const u8,
     flags: AtFlags,
 ) -> io::Error {
-    let dirfd = dirfd.as_fd();
-    imp::syscalls::execveat(dirfd, path, argv, envp, flags)
+    imp::syscalls::execveat(dirfd.as_fd(), path, argv, envp, flags)
 }
 
 /// `execve(path.as_z_str(), argv, envp)`—Execute a new command using the
