@@ -1,3 +1,5 @@
+//! Tests for [`rustix::fs`].
+
 #![cfg(not(windows))]
 #![cfg_attr(target_os = "wasi", feature(wasi_ext))]
 #![cfg_attr(io_lifetimes_use_std, feature(io_safety))]
@@ -9,8 +11,8 @@ mod flock;
 mod invalid_offset;
 mod long_paths;
 #[cfg(not(any(
-    target_os = "ios",
     target_os = "freebsd",
+    target_os = "ios",
     target_os = "macos",
     target_os = "netbsd",
     target_os = "openbsd",
@@ -24,4 +26,6 @@ mod mknodat;
 mod openat2;
 mod readdir;
 mod renameat;
+#[cfg(not(any(target_os = "netbsd", target_os = "redox", target_os = "wasi")))]
+// not implemented in libc for netbsd yet
 mod statfs;
