@@ -7,7 +7,7 @@
 #[cfg(not(windows))]
 mod dup2_to_replace_stdio;
 #[cfg(not(windows))]
-mod dup2_with;
+mod dup3;
 #[cfg(not(feature = "rustc-dep-of-std"))] // TODO
 #[cfg(not(windows))]
 mod epoll;
